#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from onf_website.skin.public.layer import IONFBaseLayer
from pyams_default_theme.component.association.viewlet import AssociationContentProvider
from pyams_template.template import override_template


override_template(context=AssociationContentProvider,
                  template='templates/viewlet.pt',
                  layer=IONFBaseLayer)

override_template(context=AssociationContentProvider,
                  name='files-action',
                  template='templates/viewlet-files-action.pt',
                  layer=IONFBaseLayer)

override_template(context=AssociationContentProvider,
                  name='links-action',
                  template='templates/viewlet-links-action.pt',
                  layer=IONFBaseLayer)

override_template(context=AssociationContentProvider,
                  name='arrow',
                  template='templates/viewlet-arrow.pt',
                  layer=IONFBaseLayer)

override_template(context=AssociationContentProvider,
                  name='frame-action',
                  template='templates/viewlet-frame-action.pt',
                  layer=IONFBaseLayer)
